#-*-coding:utf-8-*-
"""
    Outil de gestion des applications web installés sur scribe
"""
from os.path import isfile

import json
from twisted.python import log

from zephir.monitor.agents.web import Web

#from ead2.backend.actions.tools import command_statusoutput as command
from ead2.backend.actions.lib.error import exception
from ead2.backend.actions.lib.envole.install.package import Package

DISABLED_APPS = "/usr/share/ead2/backend/tmp/envole/disabled_actions"

class WebAppsConf:
    """
        Charge les applications disponibles/installés sur Scribe
    """

    def __init__(self, app_filename):
        if not isfile(app_filename):
            self.app_configuration = {}
        try:
            self.app_configuration = json.read(app_filename)
        except json.ReadException:
            log.err()
            exception("Le fichier de configuration des applications " + \
                      "est invalide, contactez votre administrateur.")

        self.app_pool = {}
        for name, conf in self.app_configuration.keys():
            version = conf.get('version')
            default_active = conf.get('default_active', 'oui')
            description = conf.get('description', name)
            creole_key = conf.get('creole_key', name)

            self.app_pool[name] = Package(name,
                                              version=version,
                                              creole_key=creole_key,
                                              default_active=default_active,
                                              description=description)
        self.filter_pool()

    def filter_pool(self):
        """
            Filtre les applications disponible selon un fichier plat local
        """
        for action in self.get_disabled_apps():
            if self.app_pool.has_key(action):
                self.app_pool[action].disable()

    @staticmethod
    def get_disabled_apps():
        """
            Renvoie la liste des applications désactivées par fichier plat
        """
        if isfile(DISABLED_APPS):
            return file(DISABLED_APPS).read().splitlines()
        else:
            return []

    def list_applications(self):
        """
            Renvoie la liste des applications
        """
        return self.app_configuration.keys()

    @staticmethod
    def get_package_version(app_name):
        """
            Renvoie la version d'un paquet
        """
        pass

    def get_applications(self):
        """
            Renvoie les objets package des applications disponibles
        """
        return self.app_pool

    def get_application(self, app_name):
        """
            Renvoie un objet package pour l'application app_name
        """
        return self.app_pool.get(app_name)

#class WebAppsInstall(WebAppsConf):
#    """
#        Installeur pour les applications web de envole
#        test_web : comme son nom l'indique
#        install: installe l'application app_name
#    """
#    @staticmethod
#    def test_web():
#        """
#            Teste la disponibilité du web
#        """
#        measure = Web("monagent_de_transit", "scribe").measure()
#        for datas in measure:
#            if datas['status'] != 'On':
#                message = "Votre serveur rencontre un problème avec le " + \
#                          "service suivant : \"%s\" " %(datas['service'],)
#                exception(message)
#        return True
#
#    @staticmethod
#    def query_auto():
#        """
#            lance un query-auto
#        """
#        ret_code, ret_value = command("/usr/bin/Query-Auto -W")
#        if ret_code:
#            log.err(ret_value)
#            exception("Erreur à la mise à niveau du listing des " + \
#                    "applications. Veuillez contacter votre administrateur")
#        else:
#            return True
#
#    def launch_installation(self, app_name, logfile="/tmp/logfile"):
#        """
#            Lance l'installation de l'application app_name (avec un at now):
#            1- Export de la variable de proxy
#            2- Lance la commande update
#            3- Lance la commande d'installation de l'application
#        """
#        ret_code, ret_value = command(self.__build_install_cmd(app_name,
#                                                               logfile),
#                                      "at now")
#        if ret_code:
#            log.err(ret_value)
#            exception("Une erreur est survenue au lancement de " + \
#                      "l'installation de \"%s\"" % (app_name,))
#        else:
#            return logfile
