#-*-coding:utf-8-*-
"""
    Outil de gestion des applications web installés sur scribe
    Couche loader (préféré installer.WebAppsInstaller)
"""
from os.path import isfile

import json
from twisted.python import log

from ead2.backend.actions.lib.error import exception
from ead2.backend.actions.lib.envole.install.package import Package

DISABLED_APPS = "/usr/share/ead2/backend/tmp/envole/disabled_actions"

class WebAppsConf:
    """
        Charge les applications disponibles/installés sur Scribe
    """

    def __init__(self, app_filename):
        if not isfile(app_filename):
            self.app_configuration = {}
        try:
            file_obj = file(app_filename, 'r')
            self.app_configuration = json.read(file_obj.read())
        except json.ReadException:
            log.err()
            exception("Le fichier de configuration des applications " + \
                      "est invalide, contactez votre administrateur.")

        self.app_pool = {}
        for name, conf in self.app_configuration.items():
            version = conf.get('version')
            default_active = conf.get('default_active', 'oui')
            description = conf.get('description', name)
            creole_key = conf.get('creole_key', name)

            self.app_pool[name] = Package(name,
                                          version=version,
                                          creole_key=creole_key,
                                          default_active=default_active,
                                          description=description)
        self.filter_pool()

    def filter_pool(self):
        """
            Filtre les applications disponible selon un fichier plat local
        """
        for action in self.get_disabled_apps():
            if self.app_pool.has_key(action):
                self.app_pool[action].disable()

    @staticmethod
    def get_disabled_apps():
        """
            Renvoie la liste des applications désactivées par fichier plat
        """
        if isfile(DISABLED_APPS):
            return file(DISABLED_APPS).read().splitlines()
        else:
            return []

    def list_applications(self):
        """
            Renvoie la liste des applications
        """
        return self.app_configuration.keys()

    @staticmethod
    def get_package_version(app_name):
        """
            Renvoie la version d'un paquet
        """
        pass

    def get_applications(self):
        """
            Renvoie les objets package des applications disponibles
        """
        return self.app_pool

    def get_application(self, app_name):
        """
            Renvoie un objet package pour l'application app_name
        """
        return self.app_pool.get(app_name)
